@@ -2,11 +2,17 @@
 #'
 #' Fetches proteome data from UniProt for the provided organism ID.
 #'
-#' @param organism_id a numeric vector of one NCBI taxonomy identifier (TaxId) for and organism of choice.
-#' @param columns a character vector of metadata columns that should be imported from UniProt (all possible columns can be found here: https://www.uniprot.org/help/uniprotkb_column_names). Note: Not more than one or two columns should be selected otherwise the function will not be able to efficiently retrieve the information. If more information is needed, \code{fetch_uniprot()} can be used with the IDs retrieved by this function.
-#' @param reviewed a logical. If true, only reviewed protein entries will be retrieved.
+#' @param organism_id a numeric value that specifies the NCBI taxonomy identifier (TaxId) for and
+#' organism.
+#' @param columns a character vector of metadata columns that should be imported from UniProt (all
+#' possible columns can be found here: https://www.uniprot.org/help/uniprotkb_column_names).
+#' Note: Not more than one or two columns should be selected otherwise the function will not be
+#' able to efficiently retrieve the information. If more information is needed, \code{fetch_uniprot()}
+#' can be used with the IDs retrieved by this function.
+#' @param reviewed a logical value that determines if only reviewed protein entries will be retrieved.
 #'
-#' @return A data frame that contains all protein metadata specified in \code{columns} for the organism of choice.
+#' @return A data frame that contains all protein metadata specified in \code{columns} for the
+#' organism of choice.
 #' @importFrom janitor make_clean_names
 #' @export
 #'
@@ -25,7 +31,9 @@ fetch_uniprot_proteome <-
       stop("No valid organism ID found.")
     }
     if (length(columns) > 3) {
-      warning("We suggest to use the fetch_uniprot function to fetch more than three columns.")
+      warning(strwrap("We suggest to use the fetch_uniprot function to fetch more than three columns.",
+        prefix = "\n", initial = ""
+      ))
     }
     url <- "http://www.uniprot.org/uniprot/?query="
     column_names <- janitor::make_clean_names(columns)
@@ -41,11 +49,10 @@ fetch_uniprot_proteome <-
         "&format=tab&columns=",
         collapsed_columns
       ))
-    result <- try_query(query_url)
+    result <- try_query(query_url, progress = FALSE, show_col_types = FALSE)
     if (is.null(result)) {
       return(result)
     }
     colnames(result) <- column_names
     result
   }
-
